#############
Xscope FileIO
#############

This library allows a program to access binary files on the host machine via xscope on xcore.ai. 

This document covers the sections on how to install and get the lirbary, how to use it, and the API reference, for both the Host and Device side.

.. toctree::
  :maxdepth: 1

  00_quickstart
  01_device
  02_host
